@@ -159,8 +159,8 @@ Term_richcmp( PyObject* first, PyObject* second, int op )
 		"unsupported operand type(s) for %s: "
 		"'%.100s' and '%.100s'",
 		pyop_str( op ),
-		first->ob_type->tp_name,
-		second->ob_type->tp_name
+		Py_TYPE( first )->tp_name,
+		Py_TYPE( second )->tp_name
 	);
 	return 0;
 }
